==> mgb-0.6.9.2.tar.gz: language/lang_french_formal_utf8/lang_import.php <==
<?php
/*
MGB 0.6.x - OpenSource PHP and MySql Guestbook
Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

==========================
lang_import.php - Français
==========================

Français formel (Vous)
This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

// header
	$lang['h_title'] = "Importation de données à partir d'une version précédente";

// general
	$lang['next_step'] = "&raquo; Continuer &raquo;";
	$lang['yes'] = "Oui";
	$lang['no'] = "Non";
	$lang['active'] = "Actif";
	$lang['inactive'] = "Inactif";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "Échoué!";

// installation
	$lang['title'] = "Importation de données à partir d'une version précédente";
	$lang['expl_import'] = "S'il vous plaît, indiquez les données de connexion de la base de données, dans laquelle se trouve l'installation de votre ancien livre d’hôtes. De plus, il faut spécifier le chemin d’accès absolu correspondant à votre ancienne installation <b>sans le nom de domaine</b>. Par exemple, au lieu de <i>http://www.exemple.fr/php/livrehotes/</i>, seulement <i>/php/livrehotes/</i>. Notez les barres obliques au début et à la fin!";

// step 1
	$lang['db_title'] = "Informations sur la base de données:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Nom de la base de données:";
	$lang['db_username'] = "Nom d’utilisateur:";
	$lang['db_password'] = "Mot de passe:";
	$lang['oldgb_path'] = "Chemin d’accès:";
	$lang['import_settings'] = "Importer les préférences:";

// errormessages step 1
	$lang['no_error'] = "Toutes les valeurs sont correctes!";
	$lang['error_1_step1'] = "S'il vous plaît, remplissez tous les champs!";
	$lang['error_2_step1'] = "La connexion à la base de données a échoué. Vérifiez vos données d’accès.";
	$lang['error_3_step1'] = "Dans le chemin que vous avez spécifié, il n'a pu être trouvé d’installation du livre d’hôtes.";
	$lang['error_4_step1'] = "La base de données que vous avez spécifiée est correcte, mais ne contient aucune installation antérieure.";

// step 2
	$lang['transfer_settings'] = "Transfert préférences…";
	$lang['transfer_entries'] = "Transfert entrées…";

// finish
	$lang['import_finish'] = "Félicitations!<br><br>Les données de votre ancienne installation MGB ont été transférées avec succès dans le MGB ".MGB_VERSION.".<br><br><a href='../admin/admin.php' title='Administration de votre livre d’hôtes'>Aller à l’administration</a><br><a href='../index.php' title='Livre d’hôtes'>Voir le livre d’hôtes</a>";
?>

==> mgb-0.6.9.5.tar.gz: language/lang_french_formal_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ========================
	// lang_import.php - French
	// ========================

	// Français formel (Vous)
	// This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

	// header
	$lang['h_title'] = "Importation de données à partir d'une version précédente";

	// general
	$lang['next_step'] = "&raquo; Continuer &raquo;";
	$lang['yes'] = "Oui";
	$lang['no'] = "Non";
	$lang['active'] = "Actif";
	$lang['inactive'] = "Inactif";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "Échoué!";

	// installation
	$lang['title'] = "Importation de données à partir d'une version précédente";
	$lang['expl_import'] = "S'il vous plaît, indiquez les données de connexion de la base de données, dans laquelle se trouve l'installation de votre ancien livre d’hôtes. De plus, il faut spécifier le chemin d’accès absolu correspondant à votre ancienne installation <b>sans le nom de domaine</b>. Par exemple, au lieu de <i>http://www.exemple.fr/php/livrehotes/</i>, seulement <i>/php/livrehotes/</i>. Notez les barres obliques au début et à la fin!";

	// step 1
	$lang['db_title'] = "Informations sur la base de données:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Nom de la base de données:";
	$lang['db_username'] = "Nom d’utilisateur:";
	$lang['db_password'] = "Mot de passe:";
	$lang['oldgb_path'] = "Chemin d’accès:";
	$lang['import_settings'] = "Importer les préférences:";

	// errormessages step 1
	$lang['no_error'] = "Toutes les valeurs sont correctes!";
	$lang['error_1_step1'] = "S'il vous plaît, remplissez tous les champs!";
	$lang['error_2_step1'] = "La connexion à la base de données a échoué. Vérifiez vos données d’accès.";
	$lang['error_3_step1'] = "Dans le chemin que vous avez spécifié, il n'a pu être trouvé d’installation du livre d’hôtes.";
	$lang['error_4_step1'] = "La base de données que vous avez spécifiée est correcte, mais ne contient aucune installation antérieure.";

	// step 2
	$lang['transfer_settings'] = "Transfert préférences…";
	$lang['transfer_entries'] = "Transfert entrées…";

	// finish
	$lang['import_finish'] = "Félicitations!<br><br>Les données de votre ancienne installation MGB ont été transférées avec succès dans le MGB ".MGB_VERSION.".<br><br><a href='../admin/admin.php' title='Administration de votre livre d’hôtes'>Aller à l’administration</a><br><a href='../index.php' title='Livre d’hôtes'>Voir le livre d’hôtes</a>";
?>
